#
# spec file for package f2c
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libf2c0
%global sover 0.23
Name:           f2c
#
Version:        20210928
Release:        bp156.3.5
Summary:        A Fortran-77 to C Translator
License:        MIT
Group:          Development/Languages/Fortran
URL:            https://www.netlib.org/f2c/
Source0:        https://www.netlib.org/f2c/src.tgz
Source1:        https://www.netlib.org/f2c/libf2c.zip
Source2:        https://www.netlib.org/f2c/f2c.pdf
Source3:        https://www.netlib.org/f2c/f2c.ps
Source4:        https://www.netlib.org/f2c/fc
Patch0:         f2c-20110801.patch
Patch1:         libf2c-20110801-format-security.patch
Patch2:         f2c-20180821.patch
Patch3:         riscv-no-fpu-excp.patch
BuildRequires:  tcsh
BuildRequires:  unzip

%description
This package uses an 'f77' script that hides the C translation process from the user.

%package -n %{libname}
Summary:        A Fortran-77 to C Translator
Group:          System/Libraries

%description -n %{libname}
This package uses an 'f77' script that hides the C translation process from the user.

%package devel
Summary:        Files for Developing with f2c
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
This package uses an 'f77' script that hides the C translation process from the user.

%prep

%setup -q -c %{name}-%{version}

mkdir libf2c
unzip -qq %{SOURCE1} -d libf2c
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Set library soversion
sed -i "s/@SOVER@/%{sover}/" libf2c/makefile.u

# PDF and PS documentation
cp %{SOURCE2} %{SOURCE3} %{SOURCE4} .

%build
%make_build -C src -f makefile.u CFLAGS="%{optflags} -fno-strict-aliasing" f2c
%make_build -C libf2c -f makefile.u CFLAGS="%{optflags} -fPIC -fno-strict-aliasing"

%install
install -D -p -m 644 src/f2c.h  %{buildroot}%{_includedir}/f2c.h
install -D -p -m 755 src/f2c    %{buildroot}%{_bindir}/f2c
install -D -p -m 644 src/f2c.1t %{buildroot}%{_mandir}/man1/f2c.1
install -D -p -m 755 libf2c/libf2c.so.%{sover} %{buildroot}%{_libdir}/libf2c.so.%{sover}
ln -sr %{buildroot}%{_libdir}/libf2c.so.%{sover} %{buildroot}%{_libdir}/libf2c.so.0
ln -sr %{buildroot}%{_libdir}/libf2c.so.%{sover} %{buildroot}%{_libdir}/libf2c.so

# Setup f77 script
sed -i "s/@lib@/%{_lib}/" fc
install -Dpm 0755 fc %{buildroot}%{_bindir}/f77

%files -n %{libname}
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_includedir}/f2c*

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_bindir}/f2c
%{_bindir}/f77
%{_mandir}/man1/f2c.1%{?ext_man}

%changelog
* Tue Jul 18 2023 Andreas Schwab <schwab@suse.de>
- riscv-no-fpu-excp.patch: RISC-V does not support any FPU exceptions
* Thu Jul  7 2022 Matthias Eliasson <elimat@opensuse.org>
- update to version 20210928
  * README: add a paragraph about the size of integers and a simple
    change to f2c.h that is appropriate when sizeof(int) == 4 and
    sizeof(long) == 8.
  * xsum.c: trivial change to banish a pedantic compiler warning.
- change versioning to date as all other major distros are doing
- add f77 script (fc)
- run spec-cleaner
* Mon Jul 15 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- correct changelog:
  Add patch:
  * libf2c-20110801-format-security.patch
- get correct release tarball (src.tgz) by running
  `osc service localrun download_files`
* Tue Aug 21 2018 mcalabkova@suse.com
- update to version 0.23
  * new patches and libraries and updated specfile according to
    Fedora version 20160102
- removed patches
  * removing obsolete patches f2c-integer.diff, f2c-malloccheck.diff
    f2c.diff, tmpfile-fix.patch and yyparse.patch and usefull, yet
    inconsistent f2c-optflags.patch
- added patches
  * patches f2c-20110801.patch to use shared library libf2c.so.0.23
    and libf2c-20110801.patch to use less memory copied from Fedora
    repository
  * patch f2c-20180821.patch released to fix optflags parsing
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Sun Jan 31 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Mar 29 2007 rguenther@suse.de
- Add unzip BuildRequires
* Mon Sep 25 2006 schwab@suse.de
- Fix heap corruption due to mishandled struct padding.
* Fri Apr  7 2006 schwab@suse.de
- Fix integer size for 64bit archs.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 15 2005 rguenther@suse.de
- fix compilation in beta.  f2cs f77 doesn't like -D_FORTIFY_SOURCE.
* Mon Nov 14 2005 rguenther@suse.de
- add yyparse.patch to fix use of undefined C code in yyparse
- add -I../.. to CFLAGS for some compiles
* Wed Jul  6 2005 fehr@suse.de
- add RPM_OPT_FLAGS to another place
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Wed Jan 12 2005 fehr@suse.de
- add security fix against tmpfile vulnerability (#49770)
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Wed Apr 23 2003 coolo@suse.de
- use BuildRoot
* Wed Jan 30 2002 coolo@suse.de
- use %%_libdir
* Fri Mar  2 2001 fehr@suse.de
- update to current version  from netlib.bell-labs.com
* Fri Nov 17 2000 fehr@suse.de
- make group tag more specific
* Fri Nov 17 2000 fehr@suse.de
- prevent conflict between f2c.h and stdlib.h of glibc 2.2
- set group tag
* Thu Jul  6 2000 fehr@suse.de
- add fixes to libf2c from netlib.bell-labs.com
* Mon Jun 26 2000 fehr@suse.de
- fix bugs caused by non-overwriteable tmp files (bugzilla #2949)
* Fri May 19 2000 fehr@suse.de
- move documentation to /usr/share/doc/packages
* Fri Feb 11 2000 fehr@suse.de
- update to newest version from netlib.bell-labs.com
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon May 31 1999 fehr@suse.de
- minor fix in f77-f2c
* Wed Nov 18 1998 ro@suse.de
- fix make.elf
- yaf77: build as elf
* Sun Oct  4 1998 ro@suse.de
- libf2c: make.elf : use gcc instead of ld to create shared lib
    (gcc knows where to find crtbeginS.o)
* Thu Sep 10 1998 fehr@suse.de
- fix possible tmp exploit in yaf77 and f77-f2c script
* Wed Aug 19 1998 fehr@suse.de
- fix possible tmp exploit in fc example script
* Mon Jul 20 1998 fehr@suse.de
- add version 1.6 of yaf77
* Tue Apr 21 1998 fehr@suse.de
- copy correct version of man-page into system
* Wed Jan  7 1998 fehr@suse.de
- fix some bugs in f77-f2c, thanks to Harald Anlauf
* Mon Oct  6 1997 fehr@suse.de
- made buildable in clean build environment
* Mon May 12 1997 fehr@suse.de
- fixed wrong links in /usr/lib
* Thu Jan  2 1997 fehr@suse.de
- changed to work with elf clib
- added sonw new scripts
